@@ -45,7 +45,6 @@ _logger = logging.getLogger(__name__)
 
 
 def _is_valid_pair(key: str, value: str) -> bool:
-
     return (
         isinstance(key, str)
         and _KEY_PATTERN.fullmatch(key) is not None
@@ -80,7 +79,7 @@ class Span(abc.ABC):
 
     @abc.abstractmethod
     def set_attributes(
-        self, attributes: typing.Dict[str, types.AttributeValue]
+        self, attributes: typing.Mapping[str, types.AttributeValue]
     ) -> None:
         """Sets Attributes.
 
@@ -530,7 +529,7 @@ class NonRecordingSpan(Span):
         pass
 
     def set_attributes(
-        self, attributes: typing.Dict[str, types.AttributeValue]
+        self, attributes: typing.Mapping[str, types.AttributeValue]
     ) -> None:
         pass
 
